@@ -61,7 +61,12 @@ role {
 		my $finished_job = $self->next_finished_job;
 		my $name         = $finished_job->stage->name;
 		my $stage        = $self->_stages->{$name};
-		$stage->_analyse_completion_state($finished_job);
+		if ($stage->_has_command) {
+			$stage->_analyse_completion_state($finished_job);
+		}
+		else {
+			$stage->_set_state( $finished_job->status ? 'fail' : 'pass' );
+		}
 		if ($stage->is_fail
 				&& $stage->_chosen_retries < $stage->choose_retries
 				&& ($finished_job->_analysis_chose_retry
