@@ -277,11 +277,7 @@ has 'command' => (
     is        => 'rw',
     isa       => 'Str',
     predicate => '_has_command',
-	trigger   => sub {
-		my $self = shift;
-		$self->_only_one( '_has_code' );
-		$self->_build_script_file;
-	},
+	trigger   => sub { shift->_only_one( '_has_code' ) },
 );
 
 =head2 code
@@ -863,12 +859,22 @@ after '_analyse_completion_state' => sub {
         my $files = $self->files;
         FILE:
         for my $file (map { ref($_) ? @$_ : $_ } $files->{out}{req} ) {
+			sleep 10 unless -e $file && -M _ <= $script_time;
             unless (-e $file && (-M _ <= $script_time)) {
                 $self->_set_state('fail');
                 $self->error(
                     "Stage (", $self->name,
                     ") status changed to failed because required output file $file was not updated"
                 );
+				if (-e $file) {
+					$self->error( "mod time: (" . -M _ . ") should be le script time ($script_time)" );
+				}
+				else {
+					$self->error( "file does not exist" );
+					sleep 10;
+					my $e = -e $file ? "does" : "does not";
+					$self->error( "after 10 seconds, it $e exist" );
+				}
                 $run->stats->{failure_detected} = "required output file $file not updated";
                 last FILE;
             }
